summaryrefslogtreecommitdiffstats
path: root/Source/cmUnixMakefileGenerator.cxx
diff options
context:
space:
mode:
authorBill Hoffman <bill.hoffman@kitware.com>2002-06-11 18:25:44 (GMT)
committerBill Hoffman <bill.hoffman@kitware.com>2002-06-11 18:25:44 (GMT)
commit344a7cff8d68dbd86f7bd4d5e6bc58b24356054e (patch)
tree5198c8e0b9a30bdbc241988b154da335cf466083 /Source/cmUnixMakefileGenerator.cxx
parent9ed9bffa6f267ad1696ec217930de74640ff4e74 (diff)
downloadCMake-344a7cff8d68dbd86f7bd4d5e6bc58b24356054e.zip
CMake-344a7cff8d68dbd86f7bd4d5e6bc58b24356054e.tar.gz
CMake-344a7cff8d68dbd86f7bd4d5e6bc58b24356054e.tar.bz2
use lower case and not short path for uniq paths on window
Diffstat (limited to 'Source/cmUnixMakefileGenerator.cxx')
-rw-r--r--Source/cmUnixMakefileGenerator.cxx12
1 files changed, 4 insertions, 8 deletions
diff --git a/Source/cmUnixMakefileGenerator.cxx b/Source/cmUnixMakefileGenerator.cxx
index 0245038..31e5085 100644
--- a/Source/cmUnixMakefileGenerator.cxx
+++ b/Source/cmUnixMakefileGenerator.cxx
@@ -1356,7 +1356,7 @@ bool cmUnixMakefileGenerator::OutputObjectDepends(std::ostream& fout)
// by the class cmMakeDepend GenerateMakefile
void cmUnixMakefileGenerator::OutputCheckDepends(std::ostream& fout)
{
- std::set<std::string> emittedShortPath;
+ std::set<std::string> emittedLowerPath;
std::set<std::string> emitted;
// Iterate over every target.
std::map<cmStdString, cmTarget>& targets = m_Makefile->GetTargets();
@@ -1388,13 +1388,9 @@ void cmUnixMakefileGenerator::OutputCheckDepends(std::ostream& fout)
{
std::string dependfile =
this->ConvertToOutputPath(cmSystemTools::CollapseFullPath(dep->c_str()).c_str());
- // use the short path function to create uniqe names
- std::string shortpath;
- if(!cmSystemTools::GetShortPath(dependfile.c_str(), shortpath))
- {
- shortpath = dependfile;
- }
- if(emittedShortPath.insert(shortpath).second)
+ // use the lower path function to create uniqe names
+ std::string lowerpath = this->LowerCasePath(dependfile.c_str());
+ if(emittedLowerPath.insert(lowerpath).second)
{
emitted.insert(dependfile);
fout << " \\\n" << dependfile ;